/**
XTC_RSRC.h
	Conveniences for setting and inquiring Xt resources.
**/


/** CREATING ARG LISTS
Sample use:
   START_ARGS;
   ARG(XmNwidth,50);
   ARG(XmNheight,25);
**/

#define MAX_ARGLIST_SIZE 100

extern Arg args[MAX_ARGLIST_SIZE];
extern Cardinal args_count;

#define NO_ARGS         args_count=0
#define START_ARGS      args_count=0

#define ARG(RNAME,RVALUE)  \
    XtSetArg (args[args_count], RNAME, RVALUE), \
    args_count++



/** SETTING RESOURCES 
Use XTCsetResourceString to set any resource whose data type is XmString;
   you provide a C string, and it performs the conversion.
**/

void
XTCsetResourceValue (Widget w, char *rsrcname, XtArgVal value);

void
XTCsetResourceString (Widget w, char *rsrcname, char *str);

#define XTCsetLabelString(W,S)   XTCsetResourceString(W,XmNlabelString,S)





/** INQUIRING RESOURCES
Use the routine that matches the data type of the resource being inquired.
Use XTCgetResourceString to inquire any resource whose data type is XmString;
   it will perform the conversion to a C string.
**/


XtArgVal
XTCgetResourceValue (Widget w, char *rsrcname);

Dimension
XTCgetResourceDimension (Widget w, char *rsrcname);

unsigned char
XTCgetResourceUChar (Widget w, char *rsrcname);

char *
XTCgetResourceString (Widget w, char *rsrcname);

#define XTCgetLabelString(W)     XTCgetResourceString(W,XmNlabelString)
#define XTCgetPosition(W,R)      ((Position)(XTCgetResourceDimension(W,R)))




/** STRING CONVERSION
These two routines provide conversion between XmString and C string formats.
**/

XmString
XTCmakeMotifString (char *str);

char *
XTCinterpretMotifString (XmString);


/** COLOR CONVERSION
This routine converts a color name into a Pixel.
The 2nd parameter can be any widget; it is used to help the routine identify
   the display involved.
Sample use:
   START_ARGS;
   ARG(XmNforeground,XTCqueryPixel("red",toplevel));
**/

Pixel 
XTCqueryPixel (char *colorname, Widget w);
